SystemOrganization addCategory: #'Seaside-Tests-Slime'!

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testCallSuperImplementation
	| object painter |
	object := self
		defineClass: #WASlimeMockObject
		superclass: #WAObject.
	self compile: 'postCopy self postCopy' in: object. 
	painter := self
		defineClass: #WASlimeMockComponent
		superclass: #WAPainter.
	self compile:  'updateRoot: aHtmlRoot self updateUrl: aHtmlRoot' in: painter.
	self
		runRule: WACallSuperImplementationRule
		selectors: #(postCopy updateRoot:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testChangesStateWhileRendering
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class addInstanceVariable: 'foo'.
	self compile: 'renderContentOn: html html div: [ foo := nil ]' in: class.
	self 
		runRule: WAChangesStateWhileRenderingRule
		selectors: #(renderContentOn:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testDoNotUseWhileRendering
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self compile: 'renderContentOn: html html div: [ self call: nil ]' in: class.
	self 
		runRule: WADoNotUseWhileRenderingRule
		selectors: #(renderContentOn:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testDoNotUseWithinCallback
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self compile: 'renderContentOn: html
		html anchor
			callback: [ html document addLoadScript: nil ];
			with: 123' in: class.
	self 
		runRule: WADoNotUseWithinCallbackRule
		selectors: #(renderContentOn:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testExtractCallbackCodeToMethod
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderInvalidOn: html
			html anchor 
				callback: [ self foo. self bar ];
				with: 1'
		classified: #(rendering).
	class
		compile: 'renderValidOn: html
			html anchor 
				callback: [ self foo ];
				with: 1'
		classified: #(rendering).
	self 
		runRule: WAExtractCallbackCodeToMethodRule
		selectors: #(renderInvalidOn:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testFixCallbackTempsMissing
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self
		compile: 'callbackTemps | r | r := OrderedCollection new. (1 to: 10) do: [ :e | r add: [ e ] ]' 
		in: class.
	self 
		runRule: WAFixCallbackTempsMissingRule
		selectors: #(callbackTemps)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testHandleRequestRule
	| class |
	class := self
		defineClass: #WASlimeMockHandler
		superclass: #WARequestHandler.
	self compile: 'handleRequest: aRequest aRequest notFound' in: class.
	self 
		runTransformation: WAHandleRequestRule
		changes: #('handleFiltered: aRequestContext aRequestContext request notFound')! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testInstantiatesComponentWhileRendering
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	self compile: 'renderContentOn: html html div: WAComponentStub new' in: class.
	self 
		runRule: WAInstantiatesComponentWhileRenderingRule
		selectors: #(renderContentOn:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testSendsRenderContentOn
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'invalid self renderContentOn: nil'
		classified: #(rendering).
	self 
		runRule: WASendsRenderContentOnRule
		selectors: #(invalid)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testSequencedAsynchronousCalls
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContent1On: html
			html div
				onClick: (html jQuery ajax callback: [  ]) , (html jQuery ajax serializeForm);
				with: ''Click me'''
		classified: #(rendering).
	class
		compile: 'renderContent2On: html
			html div
				onClick: (html jQuery ajax serializeForm; callback: [  ]) , (html jQuery effect bounce);
				with: ''Click me'''
		classified: #(rendering).
	self 
		runRule: WASequencedAsynchronousCallsRule
		selectors: #(renderContent1On: renderContent2On:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 21:59'!
testSessionExpiredRule
	| class |
	class := self
		defineClass: #WASlimeMockSession
		superclass: #WASession.
	self compile: 'expired self cleanup' in: class.
	self 
		runTransformation: WASessionExpiredRule
		changes: #('unregistered self cleanup')! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testUnnecessaryBlockPassedToBrush
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContent01On: html html div: [ ]'
		classified: #(rendering).
	class
		compile: 'renderContent02On: html html div: [ html text: 2 ]'
		classified: #(rendering).
	class
		compile: 'renderContent03On: html html div: [ html render: 3 ]'
		classified: #(rendering).
	class
		compile: 'renderContent04On: html html div class: #foo; with: [ ]'
		classified: #(rendering).
	class
		compile: 'renderContent05On: html html div class: #foo; with: [ html text: 5 ]'
		classified: #(rendering).
	class
		compile: 'renderContent06On: html html div class: #foo; with: [ html render: 6 ]'
		classified: #(rendering).
	self
		runRule: WAUnnecessaryBlockPassedToBrushRule
		selectors: #(renderContent01On: renderContent02On: renderContent03On: renderContent04On: renderContent05On: renderContent06On:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testUnnecessaryWithSentToBrush
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContentOn: html html div with: 123'
		classified: #(rendering).
	self
		runRule: WAUnnecessaryWithSentToBrushRule
		selectors: #(renderContentOn:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testUsesWrongRenderer
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContentOn: html
			html updater callback: [ :r | html div ]'
		classified: #(rendering).
	self 
		runRule: WAUsesWrongRendererRule
		selectors: #(renderContentOn:)! !

!GRSlimeTest methodsFor: '*seaside-tests-slime' stamp: 'lr 1/25/2010 22:07'!
testWithHasToBeLastMessageInCascade
	| class |
	class := self 
		defineClass: #WASlimeMockComponent
		superclass: #WAComponent.
	class
		compile: 'renderContent01On: html
			html div
				with: ''foo'';
				class: ''bar''.'
		classified: #(rendering).
	class
		compile: 'renderContent02On: html
			html div
				id: ''zork'';
				with: ''foo'';
				class: ''bar''.'
		classified: #(rendering).
	self 
		runRule: WAWithHasToBeLastMessageInCascadeRule
		selectors: #(renderContent01On: renderContent02On:)! !

!GRPackage class methodsFor: '*seaside-tests-slime' stamp: 'jok 1/26/2010 15:18'!
seasideTestsSlime
	^ self new
		name: 'Seaside-Tests-Slime';
		description: 'Unit tests for the package Seaside-Slime.';
		addDependency: 'Seaside-Slime';
		addDependency: 'Grease-Tests-Slime';
		addDependency: 'Seaside-Tests-Component';
		yourself! !
